Price descriptors
.........................................

Based on elemental prices
.............................................

One way to encode the chemistry of a material is to encode the elements via their elemental prices.
This can be useful as indicator in high-throughput screenings but also be one way of encoding the chemistry of a material (with higher emphasis on the presence of rare metals).

.. featurizer::  PriceLowerBound
    :id: PriceLowerBound
    :considers_geometry: False
    :considers_structure_graph: False
    :encodes_chemistry: True
    :scope: global
    :scalar: True
